==> com.liferay.wiki.engine.text-5.0.13.jar: org/apache/jsp/edit_005fpage_jsp.java <==
package org.apache.jsp;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import com.liferay.wiki.engine.BaseWikiEngine;
import com.liferay.wiki.model.WikiPage;

public final class edit_005fpage_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List<String> _jspx_dependants;

  static {
    _jspx_dependants = new java.util.ArrayList<String>(1);
    _jspx_dependants.add("/init.jsp");
  }

  private org.apache.jasper.runtime.TagHandlerPool _jspx_tagPool_liferay$1ui_input$1field_model_field_bean_nobody;

  private org.glassfish.jsp.api.ResourceInjector _jspx_resourceInjector;

  public java.util.List<String> getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _jspx_tagPool_liferay$1ui_input$1field_model_field_bean_nobody = org.apache.jasper.runtime.TagHandlerPool.getTagHandlerPool(getServletConfig());
  }

  public void _jspDestroy() {
    _jspx_tagPool_liferay$1ui_input$1field_model_field_bean_nobody.release();
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;

    try {
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;
      _jspx_resourceInjector = (org.glassfish.jsp.api.ResourceInjector) application.getAttribute("com.sun.appserv.jsp.resource.injector");

      out.write('\n');
      out.write('\n');
      out.write("\n\n\n\n");
      out.write('\n');
      out.write('\n');
      //  liferay-ui:input-field
      com.liferay.taglib.ui.InputFieldTag _jspx_th_liferay$1ui_input$1field_0 = (com.liferay.taglib.ui.InputFieldTag) _jspx_tagPool_liferay$1ui_input$1field_model_field_bean_nobody.get(com.liferay.taglib.ui.InputFieldTag.class);
      _jspx_th_liferay$1ui_input$1field_0.setPageContext(_jspx_page_context);
      _jspx_th_liferay$1ui_input$1field_0.setParent(null);
      _jspx_th_liferay$1ui_input$1field_0.setBean( BaseWikiEngine.getWikiPage(request) );
      _jspx_th_liferay$1ui_input$1field_0.setField("content");
      _jspx_th_liferay$1ui_input$1field_0.setModel( WikiPage.class );
      int _jspx_eval_liferay$1ui_input$1field_0 = _jspx_th_liferay$1ui_input$1field_0.doStartTag();
      if (_jspx_th_liferay$1ui_input$1field_0.doEndTag() == javax.servlet.jsp.tagext.Tag.SKIP_PAGE) {
        _jspx_tagPool_liferay$1ui_input$1field_model_field_bean_nobody.reuse(_jspx_th_liferay$1ui_input$1field_0);
        return;
      }
      _jspx_tagPool_liferay$1ui_input$1field_model_field_bean_nobody.reuse(_jspx_th_liferay$1ui_input$1field_0);
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          out.clearBuffer();
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
        else throw new ServletException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}

==> com.liferay.wiki.engine.text-6.0.10.jar: org/apache/jsp/edit_005fpage_jsp.java <==
package org.apache.jsp;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import com.liferay.wiki.engine.BaseWikiEngine;
import com.liferay.wiki.model.WikiPage;

public final class edit_005fpage_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List<String> _jspx_dependants;

  static {
    _jspx_dependants = new java.util.ArrayList<String>(1);
    _jspx_dependants.add("/init.jsp");
  }

  private org.glassfish.jsp.api.ResourceInjector _jspx_resourceInjector;

  public java.util.List<String> getDependants() {
    return _jspx_dependants;
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;

    try {
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;
      _jspx_resourceInjector = (org.glassfish.jsp.api.ResourceInjector) application.getAttribute("com.sun.appserv.jsp.resource.injector");

      out.write('\n');
      out.write('\n');
      out.write("\n\n\n\n");
      out.write('\n');
      out.write('\n');
      //  liferay-ui:input-field
      com.liferay.taglib.ui.InputFieldTag _jspx_th_liferay$1ui_input$1field_0 = (_jspx_resourceInjector != null) ? _jspx_resourceInjector.createTagHandlerInstance(com.liferay.taglib.ui.InputFieldTag.class) : new com.liferay.taglib.ui.InputFieldTag();
      _jspx_th_liferay$1ui_input$1field_0.setPageContext(_jspx_page_context);
      _jspx_th_liferay$1ui_input$1field_0.setParent(null);
      _jspx_th_liferay$1ui_input$1field_0.setBean( BaseWikiEngine.getWikiPage(request) );
      _jspx_th_liferay$1ui_input$1field_0.setField("content");
      _jspx_th_liferay$1ui_input$1field_0.setModel( WikiPage.class );
      int _jspx_eval_liferay$1ui_input$1field_0 = _jspx_th_liferay$1ui_input$1field_0.doStartTag();
      if (_jspx_th_liferay$1ui_input$1field_0.doEndTag() == javax.servlet.jsp.tagext.Tag.SKIP_PAGE) {
        if (_jspx_resourceInjector != null) _jspx_resourceInjector.preDestroy(_jspx_th_liferay$1ui_input$1field_0);
        _jspx_th_liferay$1ui_input$1field_0.release();
        return;
      }
      if (_jspx_resourceInjector != null) _jspx_resourceInjector.preDestroy(_jspx_th_liferay$1ui_input$1field_0);
      _jspx_th_liferay$1ui_input$1field_0.release();
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          out.clearBuffer();
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
        else throw new ServletException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}
